@@ -7,12 +7,8 @@
 # Imports
 # --------------------------------------------------------------------------------------
 from ._shared import MOBase
-from .address import Address
-from .association import Association
 from .employee import Employee
-from .engagement import Engagement
-from .engagement import EngagementAssociation
-from .manager import Manager
+from .facet import FacetClass
 from .organisation_unit import OrganisationUnit
 
 # --------------------------------------------------------------------------------------
@@ -21,11 +17,7 @@ from .organisation_unit import OrganisationUnit
 
 __all__ = [
     "MOBase",
-    "Address",
-    "Association",
     "Employee",
-    "Engagement",
-    "EngagementAssociation",
-    "Manager",
+    "FacetClass",
     "OrganisationUnit",
 ]
